@@ -16,8 +16,7 @@ from datetime import datetime
 from colorama import Fore
 import yake
 #tabulate, regex, networkx, jellyfish, segtok, yake
-import similar
-from similar import App
+from asolytics.similar import App, parser_similar
 import statistics
 
 parser = argparse.ArgumentParser()
@@ -42,7 +41,7 @@ options.add_argument("--headless")
 def action_parser_similar_app(bundleId):
     print(Fore.GREEN + "* * * Виконую * * *" + Fore.WHITE)
     print(Fore.RED + "Процес збору та аналізу даних може бути тривалим..." + Fore.WHITE)
-    apps = similar.parser_similar(bundleId)
+    apps = parser_similar(bundleId)
     
     x = PrettyTable()
     x.field_names = ["Назва додатку", "Bundle ID", "Ваша позиція в схожих", "Кількість завантажень"]
